@@ -6,12 +6,14 @@ OC.L10N.register(
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
     "The last viewed note cannot be accessed. " : "Den senest viste note kan ikke tilgås.",
+    "The notes folder is not accessible: %s" : "Mappen med noter er ikke tilgængelig: %s",
     "File error" : "Fejl i fil",
     "Encryption Error" : "Fejl i kryptering",
     "Error" : "Fejl",
     "No notes found" : "Ingen noter fundet",
     "Delete note" : "Slet note",
     "Favorite" : "Foretrukken",
+    "Settings" : "Indstillinger",
     "The note has unsaved changes." : "Noten har ikke gemte ændringer.",
     "Click here to try again" : "Klik her for at prøve igen",
     "Saving failed!" : "Kunne ikke gemme!",
