@@ -8,12 +8,18 @@ OC.L10N.register(
     "File error" : "Σφάλμα αρχείου",
     "Encryption Error" : "Σφάλμα κρυπτογράφησης",
     "Error" : "Σφάλμα",
+    "Uncategorized" : "Μή-κατηγοριοποιημένα",
+    "Categories" : "Κατηγορίες",
+    "All notes" : "Όλες οι σημειώσεις",
+    "Search result for \"{{search}}\"" : "Αποτέλεσμα αναζήτησης για \"{{search}}\"",
     "No notes found" : "Δεν βρέθηκαν σημειώσεις",
     "Delete note" : "Διαγραφή σημείωσης",
     "Favorite" : "Αγαπημένο",
     "Settings" : "Ρυθμίσεις",
     "Folder to store your notes" : "Φάκελος αποθήκευσης των σημειώσεών σας",
     "path to notes" : "διαδρομή στις σημειώσεις",
+    "Category" : "Κατηγορία",
+    "Edit category" : "Επεξεργασία κατηγορίας",
     "The note has unsaved changes." : "Η σημείωση έχει αλλαγές που δεν έχουν σωθεί",
     "Click here to try again" : "Κάντε κλίκ εδώ, για να δοκιμάσετε ξανά.",
     "Saving failed!" : "Απέτυχε η αποθήκευση!",
