@@ -5,9 +5,16 @@ OC.L10N.register(
     "New note" : "Ohar berria",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Gorde gabeko notak daude. Orrialdetik irtetzean aldaketa guztiak galduko dira!",
     "_%n word_::_%n words_" : ["%n hitz","%n hitz"],
+    "File error" : "Fitxategi errorea",
+    "Error" : "Errorea",
+    "Categories" : "Kategoriak",
+    "All notes" : "Ohar guztiak",
     "No notes found" : "Ez da oharrik aurkitu",
     "Delete note" : "Ezabatu oharra",
     "Favorite" : "Gogokoa",
+    "Settings" : "Ezarpenak",
+    "path to notes" : "oharretara bidea",
+    "Category" : "Kategoria",
     "The note has unsaved changes." : "Oharrak gorde gabeko aldaketak ditu.",
     "Click here to try again" : "Klik egin berriz saiatzeko",
     "Saving failed!" : "Gordetzean errorea!",
