@@ -12,6 +12,9 @@ OC.L10N.register(
     "Encryption Error" : "שגיאת הצפנה",
     "Error" : "שגיאה",
     "Distraction-free notes and writing" : "פתקים וכתיבה ללא הסחות דעת",
+    "Uncategorized" : "ללא קטגוריה",
+    "Categories" : "קטגוריות",
+    "All notes" : "כל הפתקים",
     "No search result for {{search}}" : "אין תוצאות לחיפוש אחר {{search}}",
     "No notes found" : "לא נמצאו הערות",
     "Delete note" : "מחיקת הערה",
@@ -20,6 +23,8 @@ OC.L10N.register(
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
     "path to notes" : "נתיב לפתקיות",
     "File extension for new notes" : "סיומת קובץ לפתקיות חדשות",
+    "Category" : "קטגוריה",
+    "Edit category" : "עריכת קטגוריה",
     "The note has unsaved changes." : "יש שינויים בהערה שלא נשמרו",
     "Click here to try again" : "יש ללחוץ כאן כדי לנסות שוב",
     "Saving failed!" : "השמירה נכשלה!",
