@@ -4,17 +4,25 @@ OC.L10N.register(
     "Notes" : "Jegyzetek",
     "New note" : "Új jegyzet",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek!",
+    "Please wait while new settings are applied…" : "Kérlek várj, míg az új beállítások érvénybe lépnek...",
     "_%n word_::_%n words_" : ["%n szó","%n szó"],
     "The last viewed note cannot be accessed. " : "Az utoljára megtekintett jegyzet nem elérhető.",
     "File error" : "Fájlhiba",
     "Encryption Error" : "Titkosítási hiba",
     "Error" : "Hiba",
+    "Uncategorized" : "Kategorizálatlan",
+    "Categories" : "Kategóriák",
+    "All notes" : "Összes jegyzet",
+    "No search result for {{search}} in {{SelectedCategory}}" : "Nincs keresési eredménye a {{search}} itt: {{SelectedCategory}}",
     "No notes found" : "Nincsenek jegyzetek",
     "Delete note" : "Jegyzet törlése",
     "Favorite" : "Kedvenc",
     "Settings" : "Beállítások",
     "Folder to store your notes" : "A jegyzetek tárolási mappája",
+    "path to notes" : "Megjegyzés útvonala",
     "File extension for new notes" : "Fájlkiterjesztés új jegyzetekhez",
+    "Category" : "Kategória",
+    "Edit category" : "Kategória szerkesztése",
     "The note has unsaved changes." : "A jegyzet mentetlen módosításokat tartalmaz.",
     "Click here to try again" : "Kattints ide az ismételt kísérlethez",
     "Saving failed!" : "Mentés sikertelen!",
