@@ -3,12 +3,12 @@ OC.L10N.register(
     {
     "Notes" : "ノート",
     "New note" : "新しいノート",
+    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？",
     "There are unsaved notes. Leaving the page will discard all changes!" : "保存されていないノートがあります。このページから移動するとすべての変更は破棄されます。",
     "Please wait while new settings are applied…" : "新しい設定が適用されている間お待ちください...",
     "_%n word_::_%n words_" : ["%n 単語"],
-    "Updating the note's category has failed. Is the target directory writable?" : "ノートのカテゴリを更新できませんでした。 ターゲットディレクトリは書き込み可能ですか？",
     "The last viewed note cannot be accessed. " : "最後に閲覧したノートにはアクセスできません。",
-    "The notes folder is not accessible: %s" : "ノートフォルダはアクセスできません：%s",
+    "The notes folder is not accessible: %s" : "ノートフォルダーはアクセスできません：%s",
     "File error" : "ファイルエラー",
     "Encryption Error" : "暗号化エラー",
     "Error" : "エラー",
@@ -23,7 +23,7 @@ OC.L10N.register(
     "Delete note" : "ノートを削除",
     "Favorite" : "お気に入り",
     "Settings" : "設定",
-    "Folder to store your notes" : "ノートを保存するフォルダ",
+    "Folder to store your notes" : "ノートを保存するフォルダー",
     "path to notes" : "ノートへのパス",
     "File extension for new notes" : "新しいノートのファイル拡張子",
     "Category" : "カテゴリ",
