@@ -1,16 +1,12 @@
 OC.L10N.register(
     "notes",
     {
-    "Notes" : "Užrašai",
-    "New note" : "Sukurti",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
-    "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodžių"],
+    "Please wait while new settings are applied…" : "Palaukite, kol yra taikomi nauji nustatymai…",
     "File error" : "Failo klaida",
     "Encryption Error" : "Šifravimo klaida",
     "Error" : "Klaida",
-    "No notes found" : "Nėra užrašų",
-    "Delete note" : "Ištrinti",
-    "Favorite" : "Pažymėti",
+    "Favorite" : "Svarbiausias",
     "Settings" : "Nustatymai",
     "The note has unsaved changes." : "Užrašuose yra neįrašytų pakeitimų.",
     "Click here to try again" : "Spustelėkite čia, norėdami bandyti dar kartą",
