@@ -3,6 +3,8 @@ OC.L10N.register(
     {
     "Notes" : "Anteckningar",
     "New note" : "Ny anteckning",
+    "Updating the note's category has failed. Is the target directory writable?" : "Uppdatering av anteckningens kategori misslyckades. Är målmappen skrivbar?",
+    "Updating the note's category has failed." : "Uppdatering av anteckningens kategori misslyckades.",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
     "Please wait while new settings are applied…" : "Vänta medan nya inställningar tillämpas...",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
@@ -12,6 +14,12 @@ OC.L10N.register(
     "Encryption Error" : "Krypteringsfel",
     "Error" : "Fel",
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
+    "Uncategorized" : "Okategoriserad",
+    "Categories" : "Kategorier",
+    "All notes" : "Alla anteckningar",
+    "Search result for \"{{search}}\" in {{SelectedCategory}}" : "Sökresultat för \"{{search}}\" i {{SelectedCategory}}",
+    "Search result for \"{{search}}\"" : "Sökresultat för \"{{search}}\"",
+    "No search result for {{search}} in {{SelectedCategory}}" : "Inget sökresultat för {{search}} i {{SelectedCategory}}",
     "No search result for {{search}}" : "Inget sökresultat för {{search}}",
     "No notes found" : "Inga anteckningar hittades",
     "Delete note" : "Radera anteckning",
@@ -20,6 +28,8 @@ OC.L10N.register(
     "Folder to store your notes" : "Mapp för att spara dina anteckningar",
     "path to notes" : "sökväg till anteckningar",
     "File extension for new notes" : "Filtillägg för nya anteckningar",
+    "Category" : "Kategori",
+    "Edit category" : "Redigera kategori",
     "The note has unsaved changes." : "Anteckningen har osparade ändringar.",
     "Click here to try again" : "Klicka här för att försöka igen",
     "Saving failed!" : "Misslyckades att spara!",
